Enum casper_types::account::UpdateKeyFailure
source · #[repr(i32)]#[non_exhaustive]pub enum UpdateKeyFailure {
MissingKey,
PermissionDenied,
ThresholdViolation,
}Expand description
Errors that can occur while updating the Weight of a AccountHash in an account’s
associated keys map.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingKey
The given AccountHash is not associated with the given account.
PermissionDenied
Caller doesn’t have sufficient permissions to update an associated AccountHash from the
given account.
ThresholdViolation
Updating the Weight of the given associated AccountHash would cause the total
weight of all AccountHashs to fall below one of the action thresholds for the given
account.