Struct casper_types::account::AccountHash
source · pub struct AccountHash(pub [u8; 32]);Expand description
A newtype wrapping an array which contains the raw bytes of the AccountHash, a hash of Public Key and Algorithm
Tuple Fields
0: [u8; 32]Implementations
sourceimpl AccountHash
impl AccountHash
sourcepub const fn new(value: [u8; 32]) -> AccountHash
pub const fn new(value: [u8; 32]) -> AccountHash
Constructs a new AccountHash instance from the raw bytes of an Public Key Account Hash.
sourcepub fn to_formatted_string(self) -> String
pub fn to_formatted_string(self) -> String
Formats the AccountHash for users getting and putting.
sourcepub fn from_formatted_str(input: &str) -> Result<Self, FromStrError>
pub fn from_formatted_str(input: &str) -> Result<Self, FromStrError>
Parses a string formatted as per Self::to_formatted_string() into an AccountHash.