Type Definition casper_types::account::AccountHashBytes [−][src]
pub type AccountHashBytes = [u8; 32];Expand description
A type alias for the raw bytes of an Account Hash.
pub type AccountHashBytes = [u8; 32];A type alias for the raw bytes of an Account Hash.