Data types for supporting contract headers feature.
Re-exports
pub use self::action_thresholds::ActionThresholds;pub use self::associated_keys::AssociatedKeys;pub use self::error::TryFromIntError;
Modules
- This module contains types and functions for managing action thresholds.
- This module contains types and functions for working with keys associated with an account.
Structs
- Methods and type signatures supported by a contract.
- A newtype wrapping a
HashAddrwhich references anAddressableEntityin the global state. - Type signature of a method. Order of arguments matter since can be referenced by index as well as name.
- Collection of named entry points.
- Collection of named message topics.
- A NamedKey address.
- A NamedKey value.
- Parameter to a method
- Associated error type of
TryFrom<&[u8]>forAccountHash. - Associated error type of
TryFrom<&[u8]>forContractHash. - The weight associated with public keys in an account’s associated keys.
Enums
- The various types of action which can be performed in the context of a given account.
- The address for an AddressableEntity which contains the 32 bytes and tagging information.
- The type of Package.
- Tag for the variants of
EntityKind. - Enum describing the possible access control options for a contract entry point (method).
- The entry point address.
- An enum specifying who pays for the invocation and execution of the entrypoint.
- Context of method execution
- The encaspulated representation of entrypoints.
- Set of errors which may happen when working with contract headers.
- Error returned when decoding an
AccountHashfrom a formatted string. - An error from parsing a formatted contract string
- Errors that can occur while adding a new topic.
Constants
- The prefix applied to the hex-encoded
Accountto produce a formatted string representation. - The prefix applied to the hex-encoded
Addressable Entityto produce a formatted string representation. - The prefix applied to the hex-encoded
Smart contractto produce a formatted string representation. - Default name for an entry point.
- The prefix applied to the hex-encoded
Entityto produce a formatted string representation. - Maximum number of distinct user groups.
- Maximum number of URefs which can be assigned across all user groups.
- The prefix applied to the hex-encoded
Named Keyto produce a formatted string representation. - The prefix applied to the hex-encoded
System entity account or contractto produce a formatted string representation. - The number of bytes in a serialized
Weight.
Type Aliases
- The address for an AddressableEntity which contains the 32 bytes and tagging information.
- Collection of entry point parameters.