Module casper_types::api_error
source · Expand description
Contains ApiError and associated helper functions.
Enums
- Errors which can be encountered while running a smart contract.
Functions
- Converts an
i32to aResult<(), ApiError>, where0representsOk(()), and all other inputs are mapped toErr(ApiError::<variant>). The full list of mappings can be found in the docs forApiError.