[−][src]Enum casper_types::CLType
Casper types, i.e. types which can be stored and manipulated by smart contracts.
Provides a description of the underlying data type of a CLValue.
Variants
bool primitive.
i32 primitive.
i64 primitive.
u8 primitive.
u32 primitive.
u64 primitive.
U128 large unsigned integer type.
U256 large unsigned integer type.
U512 large unsigned integer type.
() primitive.
String primitive.
Key system type.
URef system type.
PublicKey system type.
Option of a CLType.
Variable-length list of a single CLType (comparable to a Vec).
Fixed-length list of a single CLType (comparable to a Rust array).
Result with Ok and Err variants of CLTypes.
Map with keys of a single CLType and values of a single CLType.
1-ary tuple of a CLType.
2-ary tuple of CLTypes.
3-ary tuple of CLTypes.
Unspecified type.
Implementations
impl CLType[src]
pub fn serialized_length(&self) -> usize[src]
The len() of the Vec<u8> resulting from self.to_bytes().