[−][src]Enum casper_types::PublicKey
Simplified raw data type
Variants
Ed25519 public key.
Secp256k1(Secp256k1Bytes)Secp256k1 public key.
Implementations
impl PublicKey[src]
pub fn to_hex(&self) -> String[src]
Converts the public key to hex, where the first byte represents the algorithm tag.
pub fn from_hex<T: AsRef<[u8]>>(input: T) -> Result<PublicKey, FromStrError>[src]
Tries to decode the public key from its hex-representation. The hex format should be as
produced by PublicKey::to_hex().