casper_types

Enum TransactionTarget

pub enum TransactionTarget {
    Native,
    Stored {
        id: TransactionInvocationTarget,
        runtime: TransactionRuntime,
        transferred_value: u64,
    },
    Session {
        is_install_upgrade: bool,
        runtime: TransactionRuntime,
        module_bytes: Bytes,
        transferred_value: u64,
        seed: Option<[u8; 32]>,
    },
}
The execution target of a crate::Transaction.

Variants



Native

The execution target is a native operation (e.g. a transfer).



Stored

The execution target is a stored entity or package.

Fields

id: TransactionInvocationTarget

The identifier of the stored execution target.

runtime: TransactionRuntime

The execution runtime to use.

transferred_value: u64

The amount of motes to transfer before code is executed.



Session

The execution target is the included module bytes, i.e. compiled Wasm.

Fields

is_install_upgrade: bool

Flag determining if the Wasm is an install/upgrade.

runtime: TransactionRuntime

The execution runtime to use.

module_bytes: Bytes

The compiled Wasm.

transferred_value: u64

The amount of motes to transfer before code is executed.

This is for protection against phishing attack where a malicious session code drains the balance of the caller account. The amount stated here is the maximum amount that can be transferred from the caller account to the session account.

seed: Option<[u8; 32]>

The seed for the session code that is used for an installer.

Implementations

Source

impl TransactionTarget

pub fn new_native() -> Self

Returns a new TransactionTarget::Native.

pub fn new_stored( id: TransactionInvocationTarget, runtime: TransactionRuntime, transferred_value: u64, ) -> Self

Returns a new TransactionTarget::Stored.

pub fn new_session( is_install_upgrade: bool, module_bytes: Bytes, runtime: TransactionRuntime, transferred_value: u64, seed: Option<[u8; 32]>, ) -> Self

Returns a new TransactionTarget::Session.

pub fn contract_hash_addr(&self) -> Option<HashAddr>

Returns a hash_addr for a targeted contract, if known.

pub fn invocation_target(&self) -> Option<TransactionInvocationTarget>

Returns the invocation target, if any.

pub fn random(rng: &mut TestRng) -> Self

Available on crate feature testing only.

Returns a random TransactionTarget.

pub fn is_session(&self) -> bool

Returns true if the transaction target is Session.