[][src]Trait casper_types::mint::RuntimeProvider

pub trait RuntimeProvider {
    fn get_caller(&self) -> AccountHash;
fn put_key(&mut self, name: &str, key: Key);
fn get_key(&self, name: &str) -> Option<Key>; }

Provider of runtime host functionality.

Required methods

fn get_caller(&self) -> AccountHash

This method should return the caller of the current context.

fn put_key(&mut self, name: &str, key: Key)

This method should handle storing given Key under name.

fn get_key(&self, name: &str) -> Option<Key>

This method should handle obtaining a given named Key under a name.

Loading content...

Implementors

Loading content...