casper_types::runtime_footprint

Struct RuntimeFootprint

pub struct RuntimeFootprint { /* private fields */ }

Implementations

Source

impl RuntimeFootprint

pub fn new( named_keys: NamedKeys, action_thresholds: BTreeMap<u8, Weight>, associated_keys: AssociatedKeys, entry_points: EntryPoints, entity_kind: EntityKind, main_purse: Option<URef>, runtime_address: RuntimeAddress, ) -> Self

pub fn new_account_footprint(account: Account) -> Self

pub fn new_contract_footprint( contract_hash: ContractHash, contract: Contract, system_entity_type: Option<SystemEntityType>, ) -> Self

pub fn new_entity_footprint( entity_addr: EntityAddr, entity: AddressableEntity, named_keys: NamedKeys, entry_points: EntryPoints, ) -> Self

pub fn package_hash(&self) -> Option<HashAddr>

pub fn associated_keys(&self) -> &AssociatedKeys

pub fn wasm_hash(&self) -> Option<HashAddr>

pub fn hash_addr(&self) -> HashAddr

pub fn named_keys(&self) -> &NamedKeys

pub fn insert_into_named_keys(&mut self, name: String, key: Key)

pub fn named_keys_mut(&mut self) -> &mut NamedKeys

pub fn take_named_keys(self) -> NamedKeys

pub fn main_purse(&self) -> Option<URef>

pub fn set_main_purse(&mut self, purse: URef)

pub fn entry_points(&self) -> &EntryPoints

pub fn entity_kind(&self) -> EntityKind

pub fn can_authorize(&self, authorization_keys: &BTreeSet<AccountHash>) -> bool

Checks whether all authorization keys are associated with this addressable entity.

pub fn can_manage_keys_with( &self, authorization_keys: &BTreeSet<AccountHash>, ) -> bool

Checks whether the sum of the weights of all authorization keys is greater or equal to key management threshold.

pub fn can_deploy_with( &self, authorization_keys: &BTreeSet<AccountHash>, ) -> bool

Checks whether the sum of the weights of all authorization keys is greater or equal to deploy threshold.

pub fn can_upgrade_with( &self, authorization_keys: &BTreeSet<AccountHash>, ) -> bool

pub fn extract_access_rights(&self, hash_addr: HashAddr) -> ContextAccessRights

Extracts the access rights from the named keys of the addressable entity.