Struct casper_types::EraId
source · pub struct EraId(_);Expand description
Era ID newtype.
Implementations
sourceimpl EraId
impl EraId
sourcepub fn iter(&self, num_eras: u64) -> impl Iterator<Item = EraId>
pub fn iter(&self, num_eras: u64) -> impl Iterator<Item = EraId>
Returns an iterator over era IDs of num_eras future eras starting from current.
sourcepub fn iter_inclusive(&self, num_eras: u64) -> impl Iterator<Item = EraId>
pub fn iter_inclusive(&self, num_eras: u64) -> impl Iterator<Item = EraId>
Returns an iterator over era IDs of num_eras future eras starting from current, plus the
provided one.
sourcepub fn checked_add(&self, x: u64) -> Option<EraId>
pub fn checked_add(&self, x: u64) -> Option<EraId>
Returns the current era plus x, or None if that would overflow
sourcepub fn checked_sub(&self, x: u64) -> Option<EraId>
pub fn checked_sub(&self, x: u64) -> Option<EraId>
Returns the current era minus x, or None if that would be less than 0.
sourcepub fn saturating_sub(&self, x: u64) -> EraId
pub fn saturating_sub(&self, x: u64) -> EraId
Returns the current era minus x, or 0 if that would be less than 0.
sourcepub fn saturating_add(self, rhs: EraId) -> EraId
pub fn saturating_add(self, rhs: EraId) -> EraId
Returns the current era plus x, or EraId::MAX if overflow would occur.
sourcepub fn saturating_mul(&self, x: u64) -> EraId
pub fn saturating_mul(&self, x: u64) -> EraId
Returns the current era times x, or EraId::MAX if overflow would occur.
sourcepub fn is_genesis(&self) -> bool
pub fn is_genesis(&self) -> bool
Returns whether this is era 0.
sourcepub fn to_le_bytes(self) -> [u8; 8]
pub fn to_le_bytes(self) -> [u8; 8]
Returns little endian bytes.