casper_types

Struct GenesisConfigBuilder

pub struct GenesisConfigBuilder { /* private fields */ }
Available on crate feature std only.
A builder for an GenesisConfig.

Any field that isn’t specified will be defaulted. See the module docs for the set of default values.

Implementations

Source

impl GenesisConfigBuilder

pub fn new() -> Self

Creates a new ExecConfig builder.

pub fn with_accounts(self, accounts: Vec<GenesisAccount>) -> Self

Sets the genesis accounts.

pub fn with_wasm_config(self, wasm_config: WasmConfig) -> Self

Sets the Wasm config options.

pub fn with_system_config(self, system_config: SystemConfig) -> Self

Sets the system config options.

pub fn with_validator_slots(self, validator_slots: u32) -> Self

Sets the validator slots config option.

pub fn with_auction_delay(self, auction_delay: u64) -> Self

Sets the auction delay config option.

pub fn with_locked_funds_period_millis( self, locked_funds_period_millis: u64, ) -> Self

Sets the locked funds period config option.

pub fn with_round_seigniorage_rate( self, round_seigniorage_rate: Ratio<u64>, ) -> Self

Sets the round seigniorage rate config option.

pub fn with_unbonding_delay(self, unbonding_delay: u64) -> Self

Sets the unbonding delay config option.

pub fn with_genesis_timestamp_millis( self, genesis_timestamp_millis: u64, ) -> Self

Sets the genesis timestamp config option.

pub fn with_gas_hold_interval_millis( self, gas_hold_interval_millis: u64, ) -> Self

Sets the gas hold interval config option expressed as milliseconds.

pub fn with_gas_hold_balance_handling( self, gas_hold_balance_handling: HoldBalanceHandling, ) -> Self

Sets the gas hold balance handling.

pub fn with_enable_addressable_entity( self, enable_addressable_entity: bool, ) -> Self

pub fn with_storage_costs(self, storage_costs: StorageCosts) -> Self

Sets the storage_costs handling.

pub fn build(self) -> GenesisConfig

Builds a new GenesisConfig object.