pub struct SignedBlockHeader { /* private fields */ }Expand description
A block header and collection of signatures of a given block.
Implementations
Sourceimpl SignedBlockHeader
impl SignedBlockHeader
Sourcepub fn new(block_header: BlockHeader, block_signatures: BlockSignatures) -> Self
pub fn new(block_header: BlockHeader, block_signatures: BlockSignatures) -> Self
Returns a new SignedBlockHeader.
Sourcepub fn block_header(&self) -> &BlockHeader
pub fn block_header(&self) -> &BlockHeader
Returns the block header.
Sourcepub fn block_signatures(&self) -> &BlockSignatures
pub fn block_signatures(&self) -> &BlockSignatures
Returns the block signatures.
Sourcepub fn is_valid(&self) -> Result<(), SignedBlockHeaderValidationError>
pub fn is_valid(&self) -> Result<(), SignedBlockHeaderValidationError>
Returns Ok if and only if the block hash and era ID in the BlockHeader are identical to
those in the BlockSignatures.
Note that no cryptographic verification of the contained signatures is performed. For this,
see BlockSignatures::is_verified.
Sourcepub fn invalidate_era(&mut self)
Available on crate feature testing only.
pub fn invalidate_era(&mut self)
testing only.Sets the era ID contained in block_signatures to its max value, rendering it and hence
self invalid (assuming the relevant era ID for this SignedBlockHeader wasn’t already
the max value).
Sourcepub fn invalidate_last_signature(&mut self)
Available on crate feature testing only.
pub fn invalidate_last_signature(&mut self)
testing only.Replaces the signature field of the last block_signatures entry with the System variant
of crate::crypto::Signature, rendering that entry invalid.
Note that Self::is_valid will be unaffected by this as it only checks for equality in
the block hash and era ID of the header and signatures; no cryptographic verification is
performed.