pub struct ValidatorBid { /* private fields */ }Expand description
An entry in the validator map.
Implementations
Sourceimpl ValidatorBid
impl ValidatorBid
Sourcepub fn with_min_max_delegation_amount(
self,
maximum_delegation_amount: u64,
minimum_delegation_amount: u64,
) -> Self
pub fn with_min_max_delegation_amount( self, maximum_delegation_amount: u64, minimum_delegation_amount: u64, ) -> Self
Sets the maximum and minimum delegation amounts for a validators bid.
Sourceimpl ValidatorBid
impl ValidatorBid
Sourcepub fn locked(
validator_public_key: PublicKey,
bonding_purse: URef,
staked_amount: U512,
delegation_rate: DelegationRate,
release_timestamp_millis: u64,
minimum_delegation_amount: u64,
maximum_delegation_amount: u64,
reserved_slots: u32,
) -> Self
pub fn locked( validator_public_key: PublicKey, bonding_purse: URef, staked_amount: U512, delegation_rate: DelegationRate, release_timestamp_millis: u64, minimum_delegation_amount: u64, maximum_delegation_amount: u64, reserved_slots: u32, ) -> Self
Creates new instance of a bid with locked funds.
Sourcepub fn unlocked(
validator_public_key: PublicKey,
bonding_purse: URef,
staked_amount: U512,
delegation_rate: DelegationRate,
minimum_delegation_amount: u64,
maximum_delegation_amount: u64,
reserved_slots: u32,
) -> Self
pub fn unlocked( validator_public_key: PublicKey, bonding_purse: URef, staked_amount: U512, delegation_rate: DelegationRate, minimum_delegation_amount: u64, maximum_delegation_amount: u64, reserved_slots: u32, ) -> Self
Creates new instance of a bid with unlocked funds.
Sourcepub fn empty(validator_public_key: PublicKey, bonding_purse: URef) -> Self
pub fn empty(validator_public_key: PublicKey, bonding_purse: URef) -> Self
Creates a new inactive instance of a bid with 0 staked amount.
Sourcepub fn validator_public_key(&self) -> &PublicKey
pub fn validator_public_key(&self) -> &PublicKey
Gets the validator public key of the provided bid
Sourcepub fn bonding_purse(&self) -> &URef
pub fn bonding_purse(&self) -> &URef
Gets the bonding purse of the provided bid
Sourcepub fn is_locked(&self, timestamp_millis: u64) -> bool
pub fn is_locked(&self, timestamp_millis: u64) -> bool
Checks if a bid is still locked under a vesting schedule.
Returns true if a timestamp falls below the initial lockup period + 91 days release schedule, otherwise false.
Sourcepub fn is_locked_with_vesting_schedule(
&self,
timestamp_millis: u64,
vesting_schedule_period_millis: u64,
) -> bool
pub fn is_locked_with_vesting_schedule( &self, timestamp_millis: u64, vesting_schedule_period_millis: u64, ) -> bool
Checks if a bid is still locked under a vesting schedule.
Returns true if a timestamp falls below the initial lockup period + 91 days release schedule, otherwise false.
Sourcepub fn staked_amount(&self) -> U512
pub fn staked_amount(&self) -> U512
Gets the staked amount of the provided bid
Sourcepub fn staked_amount_mut(&mut self) -> &mut U512
pub fn staked_amount_mut(&mut self) -> &mut U512
Gets the staked amount of the provided bid
Sourcepub fn delegation_rate(&self) -> &DelegationRate
pub fn delegation_rate(&self) -> &DelegationRate
Gets the delegation rate of the provided bid
Sourcepub fn vesting_schedule(&self) -> Option<&VestingSchedule>
pub fn vesting_schedule(&self) -> Option<&VestingSchedule>
Returns a reference to the vesting schedule of the provided bid. None if a non-genesis
validator.
Sourcepub fn vesting_schedule_mut(&mut self) -> Option<&mut VestingSchedule>
pub fn vesting_schedule_mut(&mut self) -> Option<&mut VestingSchedule>
Returns a mutable reference to the vesting schedule of the provided bid. None if a
non-genesis validator.
Sourcepub fn reserved_slots(&self) -> u32
pub fn reserved_slots(&self) -> u32
Gets the reserved slots of the provided bid
Sourcepub fn decrease_stake(
&mut self,
amount: U512,
era_end_timestamp_millis: u64,
) -> Result<U512, Error>
pub fn decrease_stake( &mut self, amount: U512, era_end_timestamp_millis: u64, ) -> Result<U512, Error>
Decreases the stake of the provided bid
Sourcepub fn increase_stake(&mut self, amount: U512) -> Result<U512, Error>
pub fn increase_stake(&mut self, amount: U512) -> Result<U512, Error>
Increases the stake of the provided bid
Sourcepub fn with_delegation_rate(
&mut self,
delegation_rate: DelegationRate,
) -> &mut Self
pub fn with_delegation_rate( &mut self, delegation_rate: DelegationRate, ) -> &mut Self
Updates the delegation rate of the provided bid
Sourcepub fn with_reserved_slots(&mut self, reserved_slots: u32) -> &mut Self
pub fn with_reserved_slots(&mut self, reserved_slots: u32) -> &mut Self
Updates the reserved slots of the provided bid
Sourcepub fn deactivate(&mut self) -> bool
pub fn deactivate(&mut self) -> bool
Sets given bid’s inactive field to true
Sourcepub fn with_validator_public_key(
&mut self,
validator_public_key: PublicKey,
) -> &mut Self
pub fn with_validator_public_key( &mut self, validator_public_key: PublicKey, ) -> &mut Self
Sets validator public key
Sourcepub fn minimum_delegation_amount(&self) -> u64
pub fn minimum_delegation_amount(&self) -> u64
Returns minimum allowed delegation amount in motes.
Sourcepub fn maximum_delegation_amount(&self) -> u64
pub fn maximum_delegation_amount(&self) -> u64
Returns maximum allowed delegation amount in motes.
Sourcepub fn set_delegation_amount_boundaries(
&mut self,
minimum_delegation_amount: u64,
maximum_delegation_amount: u64,
)
pub fn set_delegation_amount_boundaries( &mut self, minimum_delegation_amount: u64, maximum_delegation_amount: u64, )
Sets minimum and maximum delegation amounts in motes.