Struct casper_types::system::auction::WithdrawPurse
source · pub struct WithdrawPurse { /* private fields */ }Expand description
A withdraw purse, a legacy structure.
Implementations
sourceimpl WithdrawPurse
impl WithdrawPurse
sourcepub const fn new(
bonding_purse: URef,
validator_public_key: PublicKey,
unbonder_public_key: PublicKey,
era_of_creation: EraId,
amount: U512
) -> Self
pub const fn new( bonding_purse: URef, validator_public_key: PublicKey, unbonder_public_key: PublicKey, era_of_creation: EraId, amount: U512 ) -> Self
Creates WithdrawPurse instance for an unbonding request.
sourcepub fn is_validator(&self) -> bool
pub fn is_validator(&self) -> bool
Checks if given request is made by a validator by checking if public key of unbonder is same as a key owned by validator.
sourcepub fn bonding_purse(&self) -> &URef
pub fn bonding_purse(&self) -> &URef
Returns bonding purse used to make this unbonding request.
sourcepub fn validator_public_key(&self) -> &PublicKey
pub fn validator_public_key(&self) -> &PublicKey
Returns public key of validator.
sourcepub fn unbonder_public_key(&self) -> &PublicKey
pub fn unbonder_public_key(&self) -> &PublicKey
Returns public key of unbonder.
For withdrawal requests that originated from validator’s public key through withdraw_bid
entrypoint this is equal to WithdrawPurse::validator_public_key and
WithdrawPurse::is_validator is true.
sourcepub fn era_of_creation(&self) -> EraId
pub fn era_of_creation(&self) -> EraId
Returns era which was used to create this unbonding request.