Crate casper_types

Types used to allow creation of Wasm contracts and tests for use on the Casper Platform.

Re-exports

Modules

  • Contains types and constants associated with user accounts.
  • Data types for supporting contract headers feature.
  • Contains ApiError and associated helper functions.
  • Collection of helper functions and structures to reason about amorphic RuntimeArgs.
  • Contains serialization and deserialization code for types used throughout the system.
  • Checksummed hex encoding following an EIP-55-like scheme.
  • Data types for interacting with contract level messages.
  • Data types for supporting contract headers feature.
  • Cryptographic types and operations on them
  • Types related to execution of deploys.
  • file_utilsstd-fs-io
    Utilities for handling reading from and writing to files.
  • genstesting or gens
    Contains functions for generating arbitrary values for use by Proptest.
  • Types for global state.
  • A module for the [serde(with = serde_option_time_diff)] attribute, to serialize and deserialize Option<TimeDiff> treating None as 0.
  • System modules, formerly known as “system contracts”
  • testingtesting
    An RNG for testing purposes.

Macros

  • Macro that makes it easier to construct named arguments.

Structs

Enums

Constants

Statics

Traits

Functions

  • cl_value_to_jsonjson-schema
    Returns a best-effort attempt to convert the CLValue into a meaningful JSON value.
  • Inspects key argument whether it contains a dictionary variant, and checks if stored_value contains a CLValue, then it will attempt a conversion from the held clvalue into DictionaryValue and returns the real CLValue held by it.
  • Serializes the given data structure as a pretty-printed String of JSON using serde_json::to_string_pretty(), but after first reducing any large hex-string values.
  • Returns the CLType describing a “named key” on the system, i.e. a (String, Key).

Type Aliases