Enum casper_types::account::UpdateKeyFailure[][src]

#[repr(i32)]
pub enum UpdateKeyFailure {
    MissingKey,
    PermissionDenied,
    ThresholdViolation,
}

Errors that can occur while updating the Weight of a AccountHash in an account’s associated keys map.

Variants

MissingKey

The given AccountHash is not associated with the given account.

PermissionDenied

Caller doesn’t have sufficient permissions to update an associated AccountHash from the given account.

ThresholdViolation

Updating the Weight of the given associated AccountHash would cause the total weight of all AccountHashs to fall below one of the action thresholds for the given account.