[−][src]Struct casper_types::account::AccountHash
A newtype wrapping a AccountHashBytes which is the raw bytes of
the AccountHash, a hash of Public Key and Algorithm
Implementations
impl AccountHash[src]
pub const fn new(value: AccountHashBytes) -> AccountHash[src]
Constructs a new AccountHash instance from the raw bytes of an Public Key Account Hash.
pub fn value(&self) -> AccountHashBytes[src]
Returns the raw bytes of the account hash as an array.
pub fn as_bytes(&self) -> &[u8][src]
Returns the raw bytes of the account hash as a slice.
pub fn to_formatted_string(&self) -> String[src]
Formats the AccountHash for users getting and putting.
pub fn from_formatted_str(input: &str) -> Result<Self, FromStrError>[src]
Parses a string formatted as per Self::to_formatted_string() into an AccountHash.