[−][src]Struct casper_types::auction::Bid
An entry in a founding validator map.
Fields
bonding_purse: URefThe purse that was used for bonding.
staked_amount: U512The total amount of staked tokens.
delegation_rate: DelegationRateDelegation rate
funds_locked: Option<EraId>A flag that represents a winning entry.
Some indicates locked funds for a specific era and an autowin status, and None case
means that funds are unlocked and autowin status is removed.
Implementations
impl Bid[src]
pub fn new_locked(
bonding_purse: URef,
staked_amount: U512,
funds_locked: EraId
) -> Self[src]
bonding_purse: URef,
staked_amount: U512,
funds_locked: EraId
) -> Self
Creates new instance of a bid with locked funds.
pub fn can_release_funds(&self) -> bool[src]
Checks if a given founding validator can release its funds.
pub fn can_withdraw_funds(&self) -> bool[src]
Checks if a given founding validator can withdraw its funds.