Data types for supporting contract headers feature.
Structs
- Methods and type signatures supported by a contract.
- A newtype wrapping a
HashAddrwhich references aContractin the global state. - Contract definition, metadata, and security container.
- A newtype wrapping a
HashAddrwhich references aContractPackagein the global state. - Major element of
ProtocolVersioncombined withContractVersion. - Type signature of a method. Order of arguments matter since can be referenced by index as well as name.
- Collection of named entry points.
- A collection of named keys.
- Associated error type of
TryFrom<&[u8]>forContractHash.
Enums
- A enum to determine the lock status of the contract package.
- Set of errors which may happen when working with contract headers.
- An error from parsing a formatted contract string
Constants
- Within each discrete major
ProtocolVersion, contract version resets to this value. - Serialized length of
ContractVersionKey. - Default name for an entry point
- Default name for an installer entry point
- Default name for an upgrade entry point
Type Aliases
- Automatically incremented value for a contract version within a major
ProtocolVersion. - Collection of contract versions.
- Collection of disabled contract versions. The runtime will not permit disabled contract versions to be executed.
- Major element of
ProtocolVersionaContractVersionis compatible with.