casper_types

Module crypto

Cryptographic types and operations on them

Modules

  • genstesting or gens
    Generators for asymmetric key types

Enums

Constants

Traits

Functions

  • Generates an Ed25519 keypair using the operating system’s cryptographically secure random number generator.
  • Attempts to recover a Secp256k1 PublicKey from a message and a signature over it.
  • Signs the given message using the given key pair.
  • Verifies the signature of the given message against the given public key.