Struct casper_types::runtime_args::RuntimeArgs [−][src]
Represents a collection of arguments passed to a smart contract.
Implementations
impl RuntimeArgs[src]
pub fn new() -> RuntimeArgs[src]
Create an empty RuntimeArgs instance.
pub fn try_new<F>(func: F) -> Result<RuntimeArgs, CLValueError> where
F: FnOnce(&mut RuntimeArgs) -> Result<(), CLValueError>, [src]
F: FnOnce(&mut RuntimeArgs) -> Result<(), CLValueError>,
A wrapper that lets you easily and safely create runtime arguments.
This method is useful when you have to construct a RuntimeArgs with multiple entries,
but error handling at given call site would require to have a match statement for each
RuntimeArgs::insert call. With this method you can use ? operator inside the closure and
then handle single result. When try_block will be stabilized this method could be
deprecated in favor of using those blocks.
pub fn get(&self, name: &str) -> Option<&CLValue>[src]
Gets an argument by its name.
pub fn len(&self) -> usize[src]
Get length of the collection.
pub fn is_empty(&self) -> bool[src]
Check if collection of arguments is empty.
pub fn insert<K, V>(&mut self, key: K, value: V) -> Result<(), CLValueError> where
K: Into<String>,
V: CLTyped + ToBytes, [src]
K: Into<String>,
V: CLTyped + ToBytes,
Insert new named argument into the collection.
pub fn insert_cl_value<K>(&mut self, key: K, cl_value: CLValue) where
K: Into<String>, [src]
K: Into<String>,
Insert new named argument into the collection.
pub fn to_values(&self) -> Vec<&CLValue>[src]
Returns values held regardless of the variant.