Enum casper_types::system::auction::Error [−][src]
#[repr(u8)]
pub enum Error {
Show 40 variants
MissingKey,
InvalidKeyVariant,
MissingValue,
Serialization,
TransferToBidPurse,
InvalidAmount,
BidNotFound,
ValidatorNotFound,
DelegatorNotFound,
Storage,
Bonding,
Unbonding,
ReleaseFounderStake,
GetBalance,
InvalidContext,
ValidatorFundsLocked,
InvalidCaller,
InvalidPublicKey,
BondNotFound,
CreatePurseFailed,
UnbondTooLarge,
BondTooSmall,
MissingDelegations,
MismatchedEraValidators,
MintReward,
InvalidValidatorSlotsValue,
MintReduceTotalSupply,
TransferToDelegatorPurse,
ValidatorRewardTransfer,
DelegatorRewardTransfer,
WithdrawDelegatorReward,
WithdrawValidatorReward,
TransferToUnbondingPurse,
RecordEraInfo,
CLValue,
MissingSeigniorageRecipients,
Transfer,
DelegationRateTooLarge,
DelegatorFundsLocked,
ArithmeticOverflow,
// some variants omitted
}Expand description
Errors which can occur while executing the Auction contract.
Variants
Unable to find named key in the contract’s named keys.
Given named key contains invalid variant.
Value under an uref does not exist. This means the installer contract didn’t work properly.
ABI serialization issue while reading or writing.
Triggered when contract was unable to transfer desired amount of tokens into a bid purse.
User passed invalid amount of tokens which might result in wrong values after calculation.
Unable to find a bid by account hash in active_bids map.
Validator’s account hash was not found in the map.
Delegator’s account hash was not found in the map.
Storage problem.
Raised when system is unable to bond.
Raised when system is unable to unbond.
Raised when Mint contract is unable to release founder stake.
Raised when the system is unable to determine purse balance.
Raised when an entry point is called from invalid account context.
Raised whenever a validator’s funds are still locked in but an attempt to withdraw was made.
Raised when caller is not the system account.
Raised when function is supplied a public key that does match the caller’s or does not have an associated account.
Validator is not not bonded.
Unable to create purse.
Attempted to unbond an amount which was too large.
Attempted to bond with a stake which was too small.
Raised when rewards are to be distributed to delegators, but the validator has no delegations.
The validators returned by the consensus component should match current era validators when distributing rewards.
Failed to mint reward tokens.
Invalid number of validator slots.
Failed to reduce total supply.
Triggered when contract was unable to transfer desired amount of tokens into a delegators purse.
Triggered when contract was unable to perform a transfer to distribute validators reward.
Triggered when contract was unable to perform a transfer to distribute delegators rewards.
Failed to transfer desired amount while withdrawing delegators reward.
Failed to transfer desired amount while withdrawing validators reward.
Failed to transfer desired amount into unbonding purse.
Failed to record era info.
Failed to create a crate::CLValue.
Missing seigniorage recipients for given era.
Failed to transfer funds.
Delegation rate exceeds rate.
Raised whenever a delegator’s funds are still locked in but an attempt to undelegate was made.
An arithmetic overflow has occurred.